#
# spec file for package opentyrian
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           opentyrian
Version:        2.1.20221123
Release:        bp155.1.5
Summary:        An arcade-style vertical scrolling shooter
License:        GPL-2.0-or-later
Group:          Amusements/Games/Action/Arcade
URL:            https://github.com/opentyrian/opentyrian
Source:         https://github.com/opentyrian/opentyrian/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FEATURE-UPSTREAM https://github.com/opentyrian/opentyrian/pull/13
Patch0:         appdata.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(SDL2_net)
BuildRequires:  pkgconfig(sdl2)

%description
OpenTyrian is a port of the DOS shoot-em-up Tyrian. Thanks to Jason Emery,
the developers were given a copy of the Tyrian source to port but
not redistribute. That code has since been ported from Turbo Pascal to C
using SDL, making it easily cross-platform. The 'Classic' port involves
minimal changes, but the 'Enhanced' port will feature further development.
Tyrian is an arcade-style vertical scrolling shooter. The story is set
in 20,031 where you play as Trent Hawkins, a skilled fighter-pilot employed
to fight Microsol and save the galaxy.

%prep
%autosetup -p1

%build
make %{?_smp_mflags} all \
  STRIP=/bin/true \
  prefix="%{_prefix}" \
  gamesdir="%{_datadir}" \
  OPENTYRIAN_VERSION=%{version}

%install
make %{?_smp_mflags} install \
  DESTDIR="%{buildroot}" \
  docdir="%{_docdir}/%{name}" \
  prefix="%{_prefix}" \
  gamesdir="%{_datadir}" \
  OPENTYRIAN_VERSION=%{version}
# Gamedata directory (for the Freeware Tyrian21 files
mkdir -p %{buildroot}%{_datadir}/tyrian

# Install .desktop file and appdata
cd linux
install -Dm644 %{name}.appdata.xml %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml
%suse_update_desktop_file -i %{name}
for size in 128 24 32 48; do
  install -D icons/tyrian-$size.png "%{buildroot}%{_datadir}/icons/hicolor/${size}x$size/apps/%{name}.png"
done
%fdupes -s %{buildroot}%{_datadir}

%post
echo "For running opentyrian you have to download the Tyrian Freeware game assets.
They can be be found here: https://www.camanis.net/tyrian/tyrian21.zip
Unpack them and put them into /usr/share/tyrian.
"

%files
%license COPYING
%doc %{_docdir}/%{name}
%{_bindir}/%{name}
%dir %{_datadir}/tyrian
%{_mandir}/man6/*
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/applications/%{name}.desktop
%{_datadir}/appdata/%{name}.appdata.xml

%changelog
* Sat Nov 26 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 2.1.20221123
  * Volume control is now on a logarithmic scale
  * Fixed music fade (ex. when starting a level)
  * Reworked audio mixing to reduce clipping
  * Fixed some graphical glitches
- Drop _service file, switch to git releases
* Sun Mar 20 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 2.1.20220318
  - Allow mouse pointer to leave window while in menus
* Sat Mar 12 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to current git version
  - Redesigned OpenTyrian menu
  - Reworked mouse behavior in menus so that pointer is now visible
  - Replaced JSON configuration file format with custom
    configuration file format
- Fix file has executable bits warning for opentyrian.appdata.xml
- Fix datadir for Tyrian files: /usr/share/tyrian is used
* Sun Apr 11 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to current git version
- Dropped upstream merged opl.patch
* Sun Sep  6 2020 Matthias Mailänder <mailaender@opensuse.org>
- Add opl.patch to fix the build with GCC 10
* Fri Jul 17 2020 Matthias Mailänder <mailaender@opensuse.org>
- build the released version again
- dynamically generate to wrapper to adjust libexecdir renamings
- add https://en.opensuse.org/openSUSE:AppStore support
* Mon Jun 11 2018 mardnh@gmx.de
- Update to version 2.1.20130907+hg1123
- Remove patch:
  * fix-gcc-6.patch (fixed upstream)
- Add patch:
  * opentyrian-obey-cflags.patch
- Specfile cleanup
* Thu Aug 11 2016 rpm@fthiessen.de
- Added fix-gcc-6.patch
- Some cleanup of the spec file
* Fri Dec 25 2015 mailaender@opensuse.org
- split game assets for licensing reasons
* Thu Aug  6 2015 mailaender@opensuse.org
- use source urls
- add man page
- use upstream icons and desktop files
* Tue Mar 26 2013 joop.boonen@opensuse.org
- Corrected the License
* Tue Jan 24 2012 prusnak@opensuse.org
- updated to hg build 995
* Sat Jul  2 2011 jengelh@medozas.de
- Use %%_smp_mflags for parallel building
- Strip %%clean section (not needed on BS)
* Tue Jun 30 2009 prusnak@suse.cz
- created package (SVN revision 949)
